@@ -10,11 +10,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(DARWIN)
-#include <sys/malloc.h>
-#else
-#include <malloc.h>
-#endif
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -252,7 +247,7 @@ int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
    if (ggen != NULL) {
       if (checkvalid(topobject) == -1) {
          destroynets();
-         createnets();
+         createnets(areastruct.topinstance);
       }
       if ((netid = is_resolved(&ggen, seltop, &nettop)) != 0) {
          /* Fprintf(stdout, "Net ID is %d in object %s\n", netid, nettop->name); */
